pub fn start(metrics_rx: Receiver<WebMetrics>, shutdown: Arc<AtomicBool>)Expand description
Start the web UI thread. Consumes the metrics channel and exits when the shared shutdown flag is set (or the channel is closed).
pub fn start(metrics_rx: Receiver<WebMetrics>, shutdown: Arc<AtomicBool>)Start the web UI thread. Consumes the metrics channel and exits when the shared shutdown flag is set (or the channel is closed).